.. :changelog:

History
-------

0.0.1 (11-11-2021)
---------------------

* First code creation


0.1.0 (26-11-2021)
------------------

* First official release.


0.1.1 (02-12-2021)
------------------

* Additional details added to export of accounts. Instead of only the energy label, it now includes the number of findings per severity
